-- 
-- Структура таблицы `blog_access`
-- 

DROP TABLE IF EXISTS `blog_access`;
CREATE TABLE `blog_access` (
  `group_id` int(11) unsigned default NULL,
  `user_id` int(11) unsigned default NULL,
  `allow_view_post` enum('0','1') default '0',
  `allow_edit_post` enum('0','1') default '1',
  `allow_delete_post` enum('0','1') default '1',
  `allow_view_comments` enum('0','1') default '1',
  `allow_edit_comment` enum('0','1') default '0',
  `allow_delete_comment` enum('0','1') default '1',
  `allow_comment` enum('0','1') default '0',
  UNIQUE KEY `group_id` (`group_id`),
  UNIQUE KEY `user_id` (`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Блоги. Доступ групп/пользователей к личным блогам.';

-- 
-- Структура таблицы `blog_comments`
-- 
DROP TABLE IF EXISTS `blog_comments`;
CREATE TABLE `blog_comments` (
  `comment_id` int(11) unsigned NOT NULL auto_increment,
  `post_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  `comment_time` int(11) unsigned NOT NULL default '0',
  `comment_text` text NOT NULL,
  `comment_user_ip` varchar(15) NOT NULL,
  `comment_rating` float(9,3) NOT NULL default '0.000',
  `comment_count_vote` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`comment_id`),
  KEY `post_id` (`post_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Блоги. Комментарии.';

-- 
-- Структура таблицы `blog_posts`
-- 

DROP TABLE IF EXISTS `blog_posts`;
CREATE TABLE `blog_posts` (
  `post_id` int(11) unsigned NOT NULL auto_increment,
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  `post_title` varchar(255) NOT NULL default '',
  `post_text` text NOT NULL,
  `post_tags` varchar(255) NOT NULL,
  `post_add_time` int(11) unsigned NOT NULL default '0',
  `post_edit_time` int(11) unsigned NOT NULL default '0',
  `post_edit_user_id` int(11) unsigned NOT NULL default '0',
  `privacy_post` enum('0','1','2','3') default '3',
  `privacy_comments` enum('0','1','2','3','4') default '4',
  `privacy_comment` enum('0','1','2','3','4') default '4',
  `post_count_comments` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`post_id`),
  KEY `blog_id` (`blog_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Блоги. Записи.';

-- 
-- Структура таблицы `blog_tags`
-- 

DROP TABLE IF EXISTS `blog_tags`;
CREATE TABLE `blog_tags` (
  `post_id` int(11) unsigned NOT NULL default '0',
  `post_tag` varchar(50) NOT NULL,
  KEY `post_id_tag` (`post_id`,`post_tag`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Блоги. Тэги.';

-- 
-- Структура таблицы `blogs`
-- 

DROP TABLE IF EXISTS `blogs`;
CREATE TABLE `blogs` (
  `blog_id` int(11) unsigned NOT NULL auto_increment,
  `blog_type` enum('0','1','2') NOT NULL default '0',
  `blog_name` varchar(255) NOT NULL,
  `blog_description` varchar(255) NOT NULL default '',
  `blog_add_time` int(11) unsigned default '0',
  `blog_count_users` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`blog_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Блоги.';

-- 
-- Структура таблицы `blogs_access`
-- 

DROP TABLE IF EXISTS `blogs_access`;
CREATE TABLE `blogs_access` (
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned default NULL,
  `group_id` int(11) unsigned default NULL,
  `allow_approve_user` enum('0','1') default '1',
  `allow_delete_user` enum('0','1') default '1',
  `allow_edit_post` enum('0','1') default '1',
  `allow_delete_post` enum('0','1') default '1',
  `allow_edit_comment` enum('0','1') default '0',
  `allow_delete_comment` enum('0','1') default '1',
  UNIQUE KEY `blog_id_group_id` (`blog_id`,`group_id`),
  UNIQUE KEY `blog_id_user_id` (`blog_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Блоги. Доступ групп/пользователей к коллективным блогам.';

-- 
-- Структура таблицы `blogs_user`
-- 

DROP TABLE IF EXISTS `blogs_user`;
CREATE TABLE `blogs_user` (
  `blog_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  `is_entry` enum('0','1') NOT NULL default '0',
  UNIQUE KEY `blog_id_user_id` (`blog_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Читатели блога';

-- 
-- Структура таблицы `config`
-- 

DROP TABLE IF EXISTS `config`;
CREATE TABLE `config` (
  `config_key` varchar(255) NOT NULL default '',
  `config_value` varchar(255) NOT NULL,
  `config_commentary` varchar(255) NOT NULL,
  PRIMARY KEY  (`config_key`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Настройки системы';

-- 
-- Дамп данных таблицы `config`
-- 

INSERT INTO `config` VALUES ('http_home_url', 'http://site.ru', 'Адрес, без закрывающего слеша');
INSERT INTO `config` VALUES ('home_title', 'WB Engine - Ваши умные блоги', 'Заголовок страниц');
INSERT INTO `config` VALUES ('theme', 'twilight', 'Тема');
INSERT INTO `config` VALUES ('admin_email', 'email@localhost', 'Email администратора');
INSERT INTO `config` VALUES ('allow_compress', '0', 'Сжатие включено');
INSERT INTO `config` VALUES ('allow_registration', '1', 'Регистрация открыта');
INSERT INTO `config` VALUES ('date_adjust', '0', 'Сдвиг времени');
INSERT INTO `config` VALUES ('date_format', 'd.m.y в H:i', 'Формат даты');
INSERT INTO `config` VALUES ('jpeg_quality', '85', 'Качество генерируемых jpeg-изображений');
INSERT INTO `config` VALUES ('flood_time', '30', 'Время антифлуда, сек');
INSERT INTO `config` VALUES ('html_charset', 'utf-8', 'кодировка html-страниц');
INSERT INTO `config` VALUES ('email_charset', 'utf-8', 'кодировка email-писем');
INSERT INTO `config` VALUES ('meta_description', 'wap blogs engine', 'meta description');
INSERT INTO `config` VALUES ('meta_keywords', 'wap, blogs, блоггер, социальность, система', 'meta keywords');
INSERT INTO `config` VALUES ('textarea_attributes', 'cols="30" rows="5"', '');
INSERT INTO `config` VALUES ('table_attributes', 'width="100%" cellpadding="4" cellspacing="1" border="0"', '');
INSERT INTO `config` VALUES ('avator_width', '150', 'Ширина аватора, px');
INSERT INTO `config` VALUES ('avator_height', '150', 'Высота аватора, px');
INSERT INTO `config` VALUES ('session_length', '150', 'Длина сессии, сек');
INSERT INTO `config` VALUES ('man', 'Парень', 'Мужской пол');
INSERT INTO `config` VALUES ('woman', 'Девушка', 'Женский пол');
INSERT INTO `config` VALUES ('nav_posts', '5', 'Постов на страницу, штук');
INSERT INTO `config` VALUES ('nav_comments', '5', 'Комментариев на страницу, штук');
INSERT INTO `config` VALUES ('length_im', '50', 'Длина IM в профиле, символов');
INSERT INTO `config` VALUES ('length_url', '50', 'Длина URL в профиле, символов');
INSERT INTO `config` VALUES ('length_name', '50', 'Длина имени в профиле, символов');
INSERT INTO `config` VALUES ('length_surname', '150', 'Длина фамилии в профиле, символов');
INSERT INTO `config` VALUES ('length_about', '1500', 'Длина "о себе" в профиле, символов');
INSERT INTO `config` VALUES ('length_interests', '1500', 'Длина интересов в профиле, символов');
INSERT INTO `config` VALUES ('length_phone', '50', 'Длина телефонов в профиле, символов');
INSERT INTO `config` VALUES ('length_wall_message', '500', 'Длина сообщения на стене, символов');
INSERT INTO `config` VALUES ('length_group_name', '255', 'Длина имени группы, символов');
INSERT INTO `config` VALUES ('length_group_description', '255', 'Длина описания группы, символов');
INSERT INTO `config` VALUES ('length_blog_name', '255', 'Длина имени коллективного блога, символов');
INSERT INTO `config` VALUES ('length_blog_description', '255', 'Длина описания коллективного блога, символов');
INSERT INTO `config` VALUES ('length_privmsgs_subject', '255', 'Длина темы приватного сообщения, символов');
INSERT INTO `config` VALUES ('length_privmsgs_message', '2000', 'Длина текста приватного сообщения, символов');
INSERT INTO `config` VALUES ('length_blog_post', '10000', 'Длина поста блога, символов');
INSERT INTO `config` VALUES ('length_blog_post_title', '255', 'Длина заголовка, символов');
INSERT INTO `config` VALUES ('length_blog_comment', '1000', ', Длина комментария, символов');
INSERT INTO `config` VALUES ('quota_blog_tags', '5', 'Квота меток на один посто блога, штук');
INSERT INTO `config` VALUES ('length_blog_tag', '20', 'Длина одной метки, символов');
INSERT INTO `config` VALUES ('answer_template', '%s, %s', 'Шаблон ответа на комментарий / сообщение');
INSERT INTO `config` VALUES ('privmsgs_subject_template', 'Привет, %s!', 'Шаблон темы приваного сообщения');
INSERT INTO `config` VALUES ('privmsgs_quota', '100', 'Квота приваных сообщений, штук');

-- 
-- Структура таблицы `friends`
-- 

DROP TABLE IF EXISTS `friends`;
CREATE TABLE `friends` (
  `user_id` int(11) unsigned NOT NULL default '0',
  `friend_user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `user_id_friend_user_id` (`user_id`,`friend_user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Друзья';

-- 
-- Структура таблицы `friends_entries`
-- 

DROP TABLE IF EXISTS `friends_entries`;
CREATE TABLE `friends_entries` (
  `user_id` int(11) unsigned NOT NULL default '0',
  `friend_user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `user_id_friend_user_id` (`user_id`,`friend_user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Друзья. Заявки.';

-- 
-- Структура таблицы `group_user`
-- 

DROP TABLE IF EXISTS `group_user`;
CREATE TABLE `group_user` (
  `group_id` int(11) unsigned NOT NULL default '0',
  `user_id` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `group_id_user_id` (`group_id`,`user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Участники группы';

-- 
-- Структура таблицы `groups`
-- 

DROP TABLE IF EXISTS `groups`;
CREATE TABLE `groups` (
  `group_id` int(11) unsigned NOT NULL auto_increment,
  `group_name` varchar(255) NOT NULL default '',
  `group_description` varchar(255) NOT NULL default '',
  `group_add_time` int(11) unsigned NOT NULL default '0',
  `group_count_users` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`group_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Группы';

-- 
-- Структура таблицы `privmsgs_in`
-- 

DROP TABLE IF EXISTS `privmsgs_in`;
CREATE TABLE `privmsgs_in` (
  `privmsgs_id` int(11) NOT NULL auto_increment,
  `privmsgs_user_id` int(11) NOT NULL default '0',
  `privmsgs_user_id_from` int(11) NOT NULL default '0',
  `privmsgs_read` enum('1','0') NOT NULL default '0',
  `privmsgs_time` int(11) NOT NULL default '0',
  `privmsgs_subject` varchar(255) NOT NULL default '',
  `privmsgs_message` text NOT NULL,
  PRIMARY KEY  (`privmsgs_id`),
  KEY `privmsgs_user_id` (`privmsgs_user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Входящие приватные сообщения';

-- 
-- Структура таблицы `privmsgs_out`
-- 

DROP TABLE IF EXISTS `privmsgs_out`;
CREATE TABLE `privmsgs_out` (
  `privmsgs_id` int(11) NOT NULL auto_increment,
  `privmsgs_user_id` int(11) NOT NULL default '0',
  `privmsgs_user_id_to` int(11) NOT NULL default '0',
  `privmsgs_read` int(1) NOT NULL default '0',
  `privmsgs_time` int(11) NOT NULL default '0',
  `privmsgs_subject` varchar(255) NOT NULL default '',
  `privmsgs_message` text NOT NULL,
  PRIMARY KEY  (`privmsgs_id`),
  KEY `privmsgs_user_id` (`privmsgs_user_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Исходящие приватные сообщения';

-- 
-- Структура таблицы `sessions`
-- 

DROP TABLE IF EXISTS `sessions`;
CREATE TABLE `sessions` (
  `ip` varchar(15) NOT NULL default '',
  `ua` varchar(100) NOT NULL default '',
  `page` varchar(255) NOT NULL default '',
  `user_id` int(11) unsigned NOT NULL default '0',
  `start_time` int(11) unsigned NOT NULL default '0',
  `last_time` int(11) unsigned NOT NULL default '0',
  `count_clicks` int(11) unsigned NOT NULL default '0',
  UNIQUE KEY `ip` (`ip`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Сессии';

-- 
-- Структура таблицы `users`
-- 

DROP TABLE IF EXISTS `users`;
CREATE TABLE `users` (
  `user_id` int(11) NOT NULL auto_increment,
  `user_login` varchar(25) NOT NULL default '',
  `user_email` varchar(80) NOT NULL default '',
  `user_admin_privilege` enum('0','1') NOT NULL default '0',
  `user_password` varchar(32) NOT NULL default '',
  `user_register` int(11) unsigned NOT NULL default '0',
  `user_last_visit` int(11) unsigned NOT NULL default '0',
  `user_unread_privmsgs` int(11) unsigned default '0',
  `user_count_posts` int(11) unsigned NOT NULL default '0',
  `user_count_comments` int(11) unsigned NOT NULL default '0',
  `user_last_post_time` int(11) unsigned NOT NULL default '0',
  `user_theme` varchar(255) NOT NULL default '',
  `user_date_adjust` tinyint(2) NOT NULL default '0',
  `user_privmsgs_to_email` enum('0','1') default '0',
  `user_allow_cookies` enum('0','1') default '1',
  `user_allow_images` enum('0','1') default '1',
  `user_allow_translit` enum('0','1') default '0',
  `user_hide_online` enum('0','1') NOT NULL default '0',
  `user_email_privacy` enum('0','1') NOT NULL default '0',
  `user_friends_privacy` enum('0','1','2','3') NOT NULL default '3',
  `user_friendship_privacy` enum('0','1','2') NOT NULL default '2',
  `user_privmsgs_privacy` enum('0','1','2') NOT NULL default '2',
  `user_wall_privacy` enum('0','1','2','3') NOT NULL default '3',
  `user_wall_posting_privacy` enum('0','1','2','3') NOT NULL default '3',
  `user_nav_posts` tinyint(2) unsigned NOT NULL default '5',
  `user_nav_comments` tinyint(2) unsigned NOT NULL default '5',
  `user_status` varchar(255) NOT NULL default '',
  `user_sex` enum('m','f') NOT NULL default 'm',
  `user_interests` text NOT NULL,
  `user_about` text NOT NULL,
  `user_name` varchar(50) NOT NULL default '',
  `user_surname` varchar(150) NOT NULL default '',
  `user_phone` varchar(50) NOT NULL default '',
  `user_im` varchar(50) NOT NULL default '',
  `user_url` varchar(100) NOT NULL default '',
  PRIMARY KEY  (`user_id`),
  UNIQUE KEY `user_login` (`user_login`),
  UNIQUE KEY `user_email` (`user_email`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8 COMMENT='Пользователи';

-- 
-- Структура таблицы `wall_posts`
-- 

DROP TABLE IF EXISTS `wall_posts`;
CREATE TABLE `wall_posts` (
  `wall_id` int(11) unsigned NOT NULL auto_increment,
  `user_id` int(11) unsigned NOT NULL default '0',
  `post_user_id` int(11) unsigned NOT NULL default '0',
  `post_add_time` int(11) unsigned NOT NULL default '0',
  `post_text` text NOT NULL,
  PRIMARY KEY  (`wall_id`),
  KEY `user_id` (`user_id`)
) ENGINE=MyISAM  DEFAULT CHARSET=utf8 COMMENT='Стена';
